diff --git a/IPython/html/notebookapp.py b/IPython/html/notebookapp.py
index bfac7bd..9a04bed 100644
--- a/IPython/html/notebookapp.py
+++ b/IPython/html/notebookapp.py
@@ -96,9 +96,8 @@ from .utils import url_path_join
_examples = """
ipython notebook # start the notebook
ipython notebook --profile=sympy # use the sympy profile
-ipython notebook --pylab=inline # pylab in inline plotting mode
+ipython notebook --matplotlib=inline # inline plotting mode
ipython notebook --certfile=mycert.pem # use SSL/TLS certificate
-ipython notebook --port=5555 --ip=* # Listen on port 5555, all interfaces
"""
#-----------------------------------------------------------------------------
diff --git a/IPython/qt/console/qtconsoleapp.py b/IPython/qt/console/qtconsoleapp.py
index 6610cd8..a78eb0d 100644
--- a/IPython/qt/console/qtconsoleapp.py
+++ b/IPython/qt/console/qtconsoleapp.py
@@ -81,8 +81,8 @@ from IPython.utils.localinterfaces import LOCALHOST, LOCAL_IPS
#-----------------------------------------------------------------------------
_examples = """
-ipython qtconsole # start the qtconsole
-ipython qtconsole --pylab=inline # start with pylab in inline plotting mode
+ipython qtconsole # start the qtconsole
+ipython qtconsole --matplotlib=inline # start with matplotlib inline plotting mode
"""
#-----------------------------------------------------------------------------
@@ -145,7 +145,7 @@ class IPythonQtConsoleApp(BaseIPythonApplication, IPythonConsoleApp):
The QtConsole supports various extra features beyond the Terminal IPython
shell, such as inline plotting with matplotlib, via:
- ipython qtconsole --pylab=inline
+ ipython qtconsole --matplotlib=inline
as well as saving your session as HTML, and printing the output.